@@ -9,6 +9,66 @@ from Crypto.Protocol.KDF import PBKDF2
 from random import randbytes
 
 
+def hash_(StringToHash=str, hash_code = str, return_type = "hex") -> str:
+    """
+    Miscellenious function for implementing hash algorithms.
+    currently supported hashes are:
+    SHA 224 / CODE = SHA224
+    SHA 256 / CODE = SHA256
+    SHA 512 / CODE = SHA512
+    MD5 / CODE = MD5
+    """
+    if hash_code == "SHA224":
+        hash_obj = hash.sha224(StringToHash.encode())
+        if return_type == "bytes":
+            return hash_obj.digest()
+        else:
+            return hash_obj.hexdigest()
+    if hash_code == "SHA256":
+        hash_obj = hash.sha256(StringToHash.encode())
+        if return_type == "bytes":
+            return hash_obj.digest()
+        else:
+            return hash_obj.hexdigest()
+    if hash_code == "SHA512":
+        hash_obj = hash.sha512(StringToHash.encode())
+        if return_type == "bytes":
+            return hash_obj.digest()
+        else:
+            return hash_obj.hexdigest()
+    if hash_code == "MD5":
+        hash_obj = hash.md5(StringToHash.encode())
+        if return_type == "bytes":
+            return hash_obj.digest()
+        else:
+            return hash_obj.hexdigest()
+
+
+def sec_delete(self, file_path, random_fill = True, null_fill = True, passes = 35) -> int:
+    if "/home/" not in file_path or "/." in file_path:
+        return 1
+    else:
+        with open (file_path, "wb") as file:
+            data = file.read()
+        length = len(data)
+        if random_fill is True:
+            for _ in passes:
+                with open(file_path, "wb") as file:
+                    file.write(randbytes(length))
+        if null_fill is True:
+            for _ in passes:
+                with open (file_path, "wb") as file:
+                    file.write("\x00" * length)
+        return 0
+
+
+def delete(self, path):
+    if '/home/' not in path or "/." in path:
+        return 1
+    else:
+        os.system("rm {}".format(path))
+
+
 class Ciphers:
     """
     A class for ciphering/deciphering operations.
@@ -40,31 +100,6 @@ class Ciphers:
             return key
 
 
-    def sec_delete(self, file_path, random_fill = True, null_fill = True, passes = 35) -> int:
-        if "/home/" not in file_path or "/." in file_path:
-            return 1
-        else:
-            with open (file_path, "wb") as file:
-                data = file.read()
-            length = len(data)
-            if random_fill is True:
-                for _ in passes:
-                    with open(file_path, "wb") as file:
-                        file.write(randbytes(length))
-            if null_fill is True:
-                for _ in passes:
-                    with open (file_path, "wb") as file:
-                        file.write("\x00" * length)
-            return 0
-
-
-    def delete(self, path):
-        if '/home/' not in path or "/." in path:
-            return 1
-        else:
-            os.system("rm {}".format(path))
-
-
     def check_path_validity(self, path=str or None, decrypting=bool, type_=str) -> int:
         """
         A guard clause for file operations.
@@ -116,13 +151,6 @@ class Ciphers:
         else:
             return 0
 
-
-    def hash(self, StringToHash=str) -> str:
-        # miscellaneous function for creating hashes.
-        hash_obj = hash.sha256(StringToHash.encode())
-        hash_ = hash_obj.hexdigest()
-        return hash_
-
     
     def change_encrypting_password(self, old_password = str, new_password = str):
         if self.password == old_password:
@@ -424,5 +452,3 @@ class Ciphers:
                         file.write(original_data)
 
 
-
-    
\ No newline at end of file
